==> wiremock-standalone-3.3.1-sources.jar: com/github/tomakehurst/wiremock/verification/diff/NamedCustomMatcherLine.java <==
/*
 * Copyright (C) 2015-2021 Thomas Akehurst
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.tomakehurst.wiremock.verification.diff;

import com.github.tomakehurst.wiremock.extension.Parameters;
import com.github.tomakehurst.wiremock.http.Request;
import com.github.tomakehurst.wiremock.matching.RequestMatcherExtension;

public class NamedCustomMatcherLine extends DiffLine<Request> {

  private final RequestMatcherExtension customMatcher;
  private final Parameters parameters;

  public NamedCustomMatcherLine(
      RequestMatcherExtension customMatcher, Parameters parameters, Request request) {
    super(
        "custom matcher",
        customMatcher,
        new EmptyToStringRequestWrapper(request),
        "[custom matcher: " + customMatcher.getName() + "]");
    this.customMatcher = customMatcher;
    this.parameters = parameters;
  }

  @Override
  protected boolean isExactMatch() {
    return customMatcher.match(value, parameters).isExactMatch();
  }
}

==> wiremock-standalone-3.13.1-sources.jar: com/github/tomakehurst/wiremock/verification/diff/NamedCustomMatcherLine.java <==
/*
 * Copyright (C) 2015-2024 Thomas Akehurst
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.tomakehurst.wiremock.verification.diff;

import com.github.tomakehurst.wiremock.extension.Parameters;
import com.github.tomakehurst.wiremock.http.Request;
import com.github.tomakehurst.wiremock.matching.MatchResult;
import com.github.tomakehurst.wiremock.matching.RequestMatcherExtension;

public class NamedCustomMatcherLine extends DiffLine<Request> {

  private final RequestMatcherExtension customMatcher;
  private final Parameters parameters;

  public NamedCustomMatcherLine(
      RequestMatcherExtension customMatcher, Parameters parameters, Request request) {
    super(
        "custom matcher",
        customMatcher,
        new EmptyToStringRequestWrapper(request),
        "[custom matcher: " + customMatcher.getName() + "]");
    this.customMatcher = customMatcher;
    this.parameters = parameters;
  }

  @Override
  protected boolean isExactMatch() {
    return getMatchResult().isExactMatch();
  }

  @Override
  public MatchResult getMatchResult() {
    return customMatcher.match(value, parameters);
  }
}
